Description Usage Arguments Value See Also Examples
View source: R/pre_processing.R
In the imputation stage, the areas of the missing peaks of the peak table that were not detected in the previous steps of the signal preprocessing workflow were integrated.
1 | lcms_fill_chrom_peaks(peak_table)
|
peak_table |
A table of peaks with (possibly) missing values. |
A peak table where the missing peaks have been filled.
Other dataset functions:
IPO_group_peaks(),
find_peaks_cwp(),
lcms_dataset_load(),
lcms_dataset_save(),
lcms_filter_mz(),
lcms_filter_polarity(),
lcms_filter_rt_min(),
lcms_filter_sample_type(),
lcms_meta_add(),
lcms_meta_export(),
lcms_plot_chrom_peak_image(),
lcms_plot_tics(),
lcms_rearrange_datafiles_by_class(),
lcms_retention_time_alignment_plot(),
lcms_tics(),
obiAdjust_Rtime(),
peakpicking_optimization(),
phData()
1 2 3 4 5 6 7 8 | ## Not run:
file_name <- system.file("extdata", "peak_table.rds", package = "AlpsLCMS")
peak_table <- base::readRDS(file_name)
peak_table_imputed <- lcms_fill_chrom_peaks(peak_table)
print(peak_table_imputed)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.