Description Usage Arguments Value See Also Examples
The function optimize parameters considering a set of samples for the peak picking algorithm using the IPO Package. This includes Peak Detection (‘Centwave), Retention Time Correction (‘obiwarp’) and Peak Correspondence (‘Density’).
1 2 3 4 5 6 7 8 9 | peakpicking_optimization(
dataset,
peakpickingParameters,
nSlaves = 1,
opt_path,
subdir = "plot_ipo",
plots = TRUE,
format = "mzXML"
)
|
dataset |
A lcms_dataset |
peakpickingParameters |
Parameters for peak picking |
nSlaves |
Number of slaves the optimization process should spawn. |
opt_path |
Path where optimization samples are saved. |
subdir |
Folder where surface plots are saved. If NULL they are displayed by the graphical device. |
plots |
Defines if plots should be generated (TRUE) or not (FALSE) in a subfolder called "plot_ipo" (default). |
A peak picking list with the best setting.
Other dataset functions:
IPO_group_peaks(),
find_peaks_cwp(),
lcms_dataset_load(),
lcms_dataset_save(),
lcms_fill_chrom_peaks(),
lcms_filter_mz(),
lcms_filter_polarity(),
lcms_filter_rt_min(),
lcms_filter_sample_type(),
lcms_meta_add(),
lcms_meta_export(),
lcms_plot_chrom_peak_image(),
lcms_plot_tics(),
lcms_rearrange_datafiles_by_class(),
lcms_retention_time_alignment_plot(),
lcms_tics(),
obiAdjust_Rtime(),
phData()
Other optimization functions:
default_peakpicking_params(),
lcms_convert_ipo_to_xcms(),
lcms_read_ipo_to_xcms(),
lcms_retcorgroup_optimization(),
lcms_write_opt_params()
Other visualization functions:
lcms_peak_table_boxplots(),
lcms_peak_table_pca(),
lcms_plot_chrom_peak_image(),
lcms_plot_chrom(),
lcms_plot_tics(),
lcms_retcorgroup_optimization(),
lcms_retention_time_alignment_plot()
1 2 3 4 5 6 7 8 9 10 11 | ## Not run:
opt_path <- system.file("extdata", "ipo_opt", package = "AlpsLCMS")
file_name <- system.file("extdata", "dataset_pos_rt_rs.rds", package = "AlpsLCMS")
dataset <- lcms_dataset_load(file_name)
default_peakpicking_params <- default_peakpicking_params(optimize = TRUE)
result_peakpicking <- peakpicking_optimization(dataset,
default_peakpicking_params,
opt_path = opt_path,
subdir = NULL)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.